@@ -2,5 +2,5 @@
 """
 pythonnest core package.
 """
-__author__ = "flanker"
-
+__author__ = 'Matthieu Gallet'
+__version__ = '1.0.2'
